\name{LearnCtbnParams}
\alias{LearnCtbnParams}

\title{
LearnCtbnParams
}

\description{
Learn the parameters of the CTBN object (both static and dynamic components) given fully or partially observed trajectories. 
It is possible to specify an inference engine used to perform learning in the missing data case.
}

\usage{
LearnCtbnParams (xpCtbn, trjs, inf.type="exact", num.samples=100, 
                 burn.iters=100, eps=1e-5, inf.engine=NULL)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{trjs}{list. List of dataframes in which each dataframe represents a trajectory.}

\item{inf.type}{character. Inference type: \code{exact}, \code{importance},  \code{gibbs},  \code{gibbsaux},  \code{meanfield}.}

\item{num.samples}{integer. Number of samples for \code{importance}, \code{gibbs}, \code{gibbsaux} inference engines.}

\item{burn.iters}{integer. Number of burn-in iterations for \code{gibbs}, \code{gibbsaux} inference engines.}

\item{eps}{numeric. Epsilon value for \code{meanfield} inference engine.}

\item{inf.engine}{external pointer to the inference engine C++ model.}
}

\value{
Character. Status of the learning process. \code{NULL} in the case of errors.
}

\seealso{
\code{\link{LearnCtbnStruct}}, 
\code{\link{SampleFullTrjs}}, 
\code{\link{SamplePartialTrjs}},  
\code{\link{GetBnCPTs}}, 
\code{\link{GetDynIntMats}}.
}

\examples{

# load ctbn
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
xpCtbn    <- LoadRCtbn(ctbn.file)

# parameters learning from fully observed data
samples   <- SampleFullTrjs(xpCtbn, num=100)
xpCtbn2   <- CloneCtbn(xpCtbn)
LearnCtbnParams(xpCtbn2, samples)
cptsOut2  <- GetBnCPTs(xpCtbn2)
cimsOut2  <- GetDynIntMats(xpCtbn2)
xpCtbn2   <- DeleteCtbn(xpCtbn2)
garbage   <- gc()

# parameters learning from partially observed data
samples   <- SamplePartialTrjs(xpCtbn, num=10, rem.frac=0.01)
xpCtbn2   <- CloneCtbn(xpCtbn)
inf       <- "importance";
LearnCtbnParams(xpCtbn2, samples, inf.type=inf, num.samples=100)
cptsOut2  <- GetBnCPTs(xpCtbn2)
cimsOut2  <- GetDynIntMats(xpCtbn2)
xpCtbn2   <- DeleteCtbn(xpCtbn2)
garbage   <- gc()

# delete ctbn
xpCtbn    <- DeleteCtbn(xpCtbn)
garbage   <- gc()
}

\keyword{ parameters learning }
