\name{QueryCtbnFilter}
\alias{QueryCtbnFilter}

\title{
QueryCtbnFilter
}

\description{
Perform the filtering query (i.e. the probability of the state x at time t given the trajectory up to time t).
}

\usage{
QueryCtbnFilter (xpCtbn, evid, insts, inf.type="exact", 
                 num.samples=100, burn.iters=100, eps=1e-5, inf.engine=NULL)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{evid}{dataframe. Evidence specified as a trajectory.}

\item{insts}{dataframe k x n+1. Dataframe of k instantiations in which the first column represents the time t.}

\item{inf.type}{character. Inference type: \code{exact}, \code{importance},  \code{gibbs},  \code{gibbsaux},  \code{meanfield}.}

\item{num.samples}{integer. Number of samples for \code{importance}, \code{gibbs}, \code{gibbsaux} inference engines.}

\item{burn.iters}{integer. Number of burn-in iterations for \code{gibbs}, \code{gibbsaux} inference engines.}

\item{eps}{numeric. Epsilon value for \code{meanfield} inference engine.}

\item{inf.engine}{external pointer to the inference engine C++ model.}
}

\value{Dataframe k x 2. Each row contains the time and the probability according to the \code{insts} dataframe. \code{NULL} in the case of errors.}


\seealso{
\code{\link{QueryCtbnStats}}, 
\code{\link{QueryCtbnTime}}, 
\code{\link{QueryCtbnSmooth}}.
}

\examples{

# load ctbn and trajectory
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
trj.file  <- system.file("DrugNetwork", "Trajectory.csv",    package="ctbn")
trj       <- read.table(trj.file, sep=",", header=TRUE, check.names=FALSE)
xpCtbn    <- LoadRCtbn(ctbn.file)

# sample.part is a partial trajectory (Concentration and Hungry are not observed at some time)
# insts dataframe of times and instantiations (Concentration=1, Hungry=0)
var1 <- "Concentration"
var2 <- "Hungry"
val1 <- 1
val2 <- 0
sample.part <- trj
sample.part[,var1] <- -1
sample.part[,var2] <- -1
time  <- seq(0,10,0.01)
vals1 <- rep(val1,length(time))
vals2 <- rep(val2,length(time))
insts <- data.frame(time,vals1,vals2)
names(insts) <- c("Time",var1,var2)

# output: dataframe (time, probability)
x <- QueryCtbnFilter(xpCtbn,sample.part,insts)

# plot output
tlt <- paste (paste(var1,val1,sep="="),paste(var2,val2,sep="="),sep=", ")
plot(x,main=tlt,xlab="Time",ylab="Probability",type="l")

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ query: filtering }
