\name{QueryCtbnTime}
\alias{QueryCtbnTime}

\title{
QueryCtbnTime
}

\description{
Perform the query to the CTBN model about the expected time that the process stays in some states.
}

\usage{
QueryCtbnTime (xpCtbn, evid, insts, inf.type="exact", 
               num.samples=100, burn.iters=100, eps=1e-5, inf.engine=NULL)
}

\arguments{

\item{xpCtbn}{external pointer to the CTBN C++ model.}

\item{evid}{dataframe. Evidence specified as a trajectory.}

\item{insts}{dataframe k x n. Dataframe of k instantiations.}

\item{inf.type}{character. Inference type: \code{exact}, \code{importance},  \code{gibbs},  \code{gibbsaux},  \code{meanfield}.}

\item{num.samples}{integer. Number of samples for \code{importance}, \code{gibbs}, \code{gibbsaux} inference engines.}

\item{burn.iters}{integer. Number of burn-in iterations for \code{gibbs}, \code{gibbsaux} inference engines.}

\item{eps}{numeric. Epsilon value for \code{meanfield} inference engine.}

\item{inf.engine}{external pointer to the inference engine C++ model.}
}

\value{Dataframe k x 1. Each row contains the expected time that the process stays in the specified state. \code{NULL} in the case of errors.}

\seealso{
\code{\link{QueryCtbnStats}}, 
\code{\link{QueryCtbnFilter}}, 
\code{\link{QueryCtbnSmooth}}.
}

\examples{

# load ctbn and trajectory
ctbn.file <- system.file("DrugNetwork", "DrugNetwork.rctbn", package="ctbn")
trj.file  <- system.file("DrugNetwork", "Trajectory.csv",    package="ctbn")
trj       <- read.table(trj.file, sep=",", header=TRUE, check.names=FALSE)
xpCtbn    <- LoadRCtbn(ctbn.file)

# sample.part is a partial trajectory (Eating and Drowsy are not observed at some time)
# insts dataframe of instantiations
var1 <- "Eating"
var2 <- "Drowsy"
sample.part <- trj
sample.part[5,var1]=-1
sample.part[6,var2]=-1
insts <- trj[7:8,c(3:4)]
print(insts)

print(QueryCtbnTime(xpCtbn,sample.part,insts))

# delete ctbn
xpCtbn  <- DeleteCtbn(xpCtbn)
garbage <- gc()
}

\keyword{ query: expected time given states}
